library(lfe)
library(zoo)
library(stargazer)
library(aTSA)

##point this to where you have saved the two data files that need loading
loc <- "/Users/jjreade/Dropbox/Research/James and Jan/Replication/"

##load attendance data collected from 11v11.com, the website of the Association of Football Statisticians.
att.all <- read.csv(paste0(loc,"all-english-matches2.csv"),stringsAsFactors = FALSE)

att.all$date <- as.Date(att.all$date,"%d %B %Y")  ##sort out date
att.all <- att.all[is.na(att.all$date)==FALSE,]
att.all$season <- as.numeric(gsub("season-","",att.all$year))

##some duplicate entries remain - cup matches between different division teams
att.all <- att.all[duplicated(att.all$filename)==FALSE,]

att.all$competition <- gsub("^\\s+|\\s+$","",att.all$competition)
att.all$tier <- as.numeric(att.all$competition=="Premier League" | att.all$competition=="League Division One") + 2*as.numeric(att.all$competition=="League Division 1" | att.all$competition=="League Division Two" | att.all$competition=="League Championship") + 3*as.numeric(att.all$competition=="League Division 2" | att.all$competition=="League Division Three" | att.all$competition=="League One") + 4*as.numeric(att.all$competition=="League Division 3" | att.all$competition=="League Division Four" | att.all$competition=="League Two") + 3.1*as.numeric(att.all$competition=="Division Three (North)") + 3.2*as.numeric(att.all$competition=="Division Three (South)")

##aggregate to annual average attendance
yearly.all <- aggregate(att.all$attendance[att.all$date<"2020-03-15"],
                        by=list(att.all$season[att.all$date<"2020-03-15"]),FUN=mean,na.rm=TRUE)
colnames(yearly.all) <- c("season","attendance")

##aggregate to annual average attendance by competition
yearly.att <- aggregate(att.all$attendance[att.all$date<"2020-03-15"],
                        by=list(att.all$season[att.all$date<"2020-03-15"],
                                att.all$tier[att.all$date<"2020-03-15"]),FUN=mean,na.rm=TRUE)
colnames(yearly.att) <- c("season","competition","attendance")

##aggregate to annual average attendance by team
yearly.club <- aggregate(att.all$attendance[att.all$date<"2020-03-15"],
                         by=list(att.all$season[att.all$date<"2020-03-15"],
                                 att.all$team1[att.all$date<"2020-03-15"]),FUN=mean,na.rm=TRUE)
colnames(yearly.club) <- c("season","club","attendance")

#record the division a club was in each year
yearly.club.div <- aggregate(att.all$tier[att.all$date<"2020-03-15" & att.all$tier>0],
                             by=list(att.all$season[att.all$date<"2020-03-15" & att.all$tier>0],
                                     att.all$team1[att.all$date<"2020-03-15" & att.all$tier>0]),FUN=mean,na.rm=TRUE)
colnames(yearly.club.div) <- c("season","club","tier")

#merge in division info per club per year
yearly.club <- merge(yearly.club,yearly.club.div,by=c("season","club"),all.x=TRUE)

yearly.club.n <- data.frame(table(yearly.club$club),stringsAsFactors = FALSE)
colnames(yearly.club.n) <- c("club","n.seasons")
yearly.club.n$club <- as.character(yearly.club.n$club)
yearly.club <- merge(yearly.club,yearly.club.n,by=c("club"),all.x=TRUE)

##make wide dataset with column per division
yearly.wide <- merge(yearly.all,yearly.att[yearly.att$competition==0,c("season","attendance")],
                     by=c("season"),suffixes = c(".all",".cup"),all.x=TRUE)
yearly.wide <- merge(yearly.wide,yearly.att[yearly.att$competition==1,c("season","attendance")],
                     by=c("season"),all.x=TRUE)
yearly.wide <- merge(yearly.wide,yearly.att[yearly.att$competition==2,c("season","attendance")],
                     suffixes = c(".EPL",".EFLC"),by=c("season"),all.x=TRUE)
yearly.wide <- merge(yearly.wide,yearly.att[yearly.att$competition==3,c("season","attendance")],
                     by=c("season"),all.x=TRUE)
yearly.wide <- merge(yearly.wide,yearly.att[yearly.att$competition==4,c("season","attendance")],
                     suffixes = c(".EFL1",".EFL2"),by=c("season"),all.x=TRUE)
yearly.wide <- merge(yearly.wide,yearly.att[yearly.att$competition==3.1,c("season","attendance")],
                     by=c("season"),all.x=TRUE)
yearly.wide <- merge(yearly.wide,yearly.att[yearly.att$competition==3.2,c("season","attendance")],
                     suffixes = c(".D3N",".D3S"),by=c("season"),all.x=TRUE)

##load up unemployment data (from the Bank of England's Millenium of Economic Data)
be.data <- read.csv(paste0(loc,"boe-millenium-data.csv"),stringsAsFactors = FALSE)
##add in the observations for 2017--2020
be.data$Year[932:935] <- 2017:2020
be.data$Unemployment.rate[932:935] <- c(4.4,4.1,3.8,4.5)

##merge in unemployment information
yearly.wide <- merge(yearly.wide,be.data[,c("Year","Unemployment.rate")],by.x=c("season"),by.y=c("Year"),all.x = TRUE)

##create lagged variables
yearly.wide$att.1 <- c(NA,yearly.wide$attendance.all[-NROW(yearly.wide)])
yearly.wide$u.1 <- c(NA,yearly.wide$Unemployment.rate[-NROW(yearly.wide)])

###merge in unemployment to long datasets
yearly.att <- merge(yearly.att,be.data[,c("Year","Unemployment.rate")],by.x=c("season"),by.y=c("Year"),all.x=TRUE)
yearly.club <- merge(yearly.club,be.data[,c("Year","Unemployment.rate")],by.x=c("season"),by.y=c("Year"),all.x=TRUE)
att.all <- merge(att.all,be.data[,c("Year","Unemployment.rate")],by.x=c("season"),by.y=c("Year"),all.x=TRUE)

yearly.club$competition <- yearly.club$tier
yearly.club$competition[yearly.club$tier==3 | yearly.club$tier==3.2] <- 3
yearly.club$competition[yearly.club$tier==4 | yearly.club$tier==3.1] <- 4

##create lagged information in long datasets
yearly.att <- yearly.att[order(yearly.att$competition,yearly.att$season),]
yearly.att$att.1 <- c(NA,yearly.att$attendance[-NROW(yearly.att)])
yearly.att$u.1 <- c(NA,yearly.att$Unemployment.rate[-NROW(yearly.att)])
yearly.att$comp.1 <- c(NA,yearly.att$competition[-NROW(yearly.att)])
yearly.att$att.1[yearly.att$comp.1!=yearly.att$competition] <- NA
yearly.att$u.1[yearly.att$comp.1!=yearly.att$competition] <- NA
yearly.att$att.1[yearly.att$competition==3 & yearly.att$season==1959] <- yearly.att$attendance[yearly.att$competition==3.2 & yearly.att$season==1958]
yearly.att$att.1[yearly.att$competition==4 & yearly.att$season==1959] <- yearly.att$attendance[yearly.att$competition==3.1 & yearly.att$season==1958]
yearly.att$u.1[yearly.att$competition==3 & yearly.att$season==1959] <- yearly.att$u.1[yearly.att$competition==2 & yearly.att$season==1959]
yearly.att$u.1[yearly.att$competition==4 & yearly.att$season==1959] <- yearly.att$u.1[yearly.att$competition==2 & yearly.att$season==1959]

##figure 1

jpeg(paste0("fig1-",Sys.Date(),".jpg"),height=6,width=10,units = "in",res = 300)
par(mar = c(5.1, 4.1, 4.1, 4.1))
plot(yearly.att$season[yearly.att$competition==1 & yearly.att$season<1916],
     yearly.att$attendance[yearly.att$competition==1 & yearly.att$season<1916],type="l",
     xlim = range(1889,2020),
     ylim = range(yearly.att$attendance[yearly.att$season<2021 & yearly.att$season!=1940],na.rm=TRUE),
     main="Average Annual Football Attendances by Division since 1888",
     ylab="Attendance",xlab="Season (year ending)")
lines(yearly.att$season[yearly.att$competition==1 & yearly.att$season>1919 & yearly.att$season<1940],
      yearly.att$attendance[yearly.att$competition==1 & yearly.att$season>1919 & yearly.att$season<1940],type="l")
lines(yearly.att$season[yearly.att$competition==1 & yearly.att$season>1945 & yearly.att$season<2021],
      yearly.att$attendance[yearly.att$competition==1 & yearly.att$season>1945 & yearly.att$season<2021],type="l")

lines(yearly.att$season[yearly.att$competition==0 & yearly.att$season<1916],
      yearly.att$attendance[yearly.att$competition==0 & yearly.att$season<1916],type="l",col="grey")
lines(yearly.att$season[yearly.att$competition==0 & yearly.att$season>1919 & yearly.att$season<1940],
      yearly.att$attendance[yearly.att$competition==0 & yearly.att$season>1919 & yearly.att$season<1940],
      type="l",col="grey")
lines(yearly.att$season[yearly.att$competition==0 & yearly.att$season>1945 & yearly.att$season<2021],
      yearly.att$attendance[yearly.att$competition==0 & yearly.att$season>1945 & yearly.att$season<2021],
      type="l",col="grey")

lines(yearly.att$season[yearly.att$competition==2 & yearly.att$season<1916],
      yearly.att$attendance[yearly.att$competition==2 & yearly.att$season<1916],type="l",lty=2)
lines(yearly.att$season[yearly.att$competition==2 & yearly.att$season>1919 & yearly.att$season<1940],
      yearly.att$attendance[yearly.att$competition==2 & yearly.att$season>1919 & yearly.att$season<1940],
      type="l",lty=2)
lines(yearly.att$season[yearly.att$competition==2 & yearly.att$season>1945 & yearly.att$season<2021],
      yearly.att$attendance[yearly.att$competition==2 & yearly.att$season>1945 & yearly.att$season<2021],
      type="l",lty=2)

lines(yearly.att$season[yearly.att$competition==3.2 & yearly.att$season<1940],yearly.att$attendance[yearly.att$competition==3.2 & yearly.att$season<1940],type="l",lty=3)
lines(yearly.att$season[yearly.att$competition==3.2 & yearly.att$season>1940],yearly.att$attendance[yearly.att$competition==3.2 & yearly.att$season>1940],type="l",lty=3)

lines(yearly.att$season[yearly.att$competition==3.1 & yearly.att$season<1940],yearly.att$attendance[yearly.att$competition==3.1 & yearly.att$season<1940],type="l",lty=4)
lines(yearly.att$season[yearly.att$competition==3.1 & yearly.att$season>1940],yearly.att$attendance[yearly.att$competition==3.1 & yearly.att$season>1940],type="l",lty=4)

lines(yearly.att$season[yearly.att$competition==3 & yearly.att$season<2021 & yearly.att$season!=1940],yearly.att$attendance[yearly.att$competition==3 & yearly.att$season<2021 & yearly.att$season!=1940],type="l",lty=3)
lines(yearly.att$season[yearly.att$competition==4 & yearly.att$season<2021 & yearly.att$season!=1940],yearly.att$attendance[yearly.att$competition==4 & yearly.att$season<2021 & yearly.att$season!=1940],type="l",lty=4)

abline(v=c(1915,1919,1939,1945,1959))
par(new=TRUE)
plot(yearly.att$season[yearly.att$competition==0 & yearly.att$season<2021],
     yearly.att$Unemployment.rate[yearly.att$competition==0 & yearly.att$season<2021],type="l",col=2,
     xaxt="n",yaxt="n",xlab="",ylab="")
axis(side=4)
mtext("Unemployment Rate", side = 4, line = 3)
legend("topleft",bty="n",col=c(1,1,1,1,"grey",2),lty=c(1,2,3,4,1,1),
       legend=c("Premier League","Championship","League One",
                "League Two","Cups",
                "Unemployment Rate"))
dev.off()

##final regressions 

summary(att.ue.all.0a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[yearly.att$competition==0 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.0a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[yearly.att$competition==0 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.0 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[yearly.att$competition==0 & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.0 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[yearly.att$competition==0 & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.1a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[yearly.att$competition==1 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.1a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[yearly.att$competition==1 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.1 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[yearly.att$competition==1 & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.1 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[yearly.att$competition==1 & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.2a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[yearly.att$competition==2 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.2a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[yearly.att$competition==2 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.2 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[yearly.att$competition==2 & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.2 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[yearly.att$competition==2 & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.3a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[(yearly.att$competition==3 | yearly.att$competition==3.2) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.3a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[(yearly.att$competition==3 | yearly.att$competition==3.2) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.3 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[(yearly.att$competition==3 | yearly.att$competition==3.2) & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.3 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[(yearly.att$competition==3 | yearly.att$competition==3.2) & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.4a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[(yearly.att$competition==4 | yearly.att$competition==3.1) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.4a <- lm(log(attendance) ~ log(Unemployment.rate),data=yearly.att[(yearly.att$competition==4 | yearly.att$competition==3.1) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.final.4 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[(yearly.att$competition==4 | yearly.att$competition==3.1) & yearly.att$season!=1940 & yearly.att$season>1920,],na.action=na.exclude))
summary(att.ue.all.4 <- lm(log(attendance) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.att[(yearly.att$competition==4 | yearly.att$competition==3.1) & yearly.att$season!=1940,],na.action=na.exclude))
summary(att.ue.final.alla <- lm(log(attendance.all) ~ log(Unemployment.rate),data=yearly.wide[is.na(yearly.wide$Unemployment.rate)==FALSE & yearly.wide$season!=1940 & yearly.wide$season>1920,],na.action=na.exclude))
summary(att.ue.final.all <- lm(log(attendance.all) ~ log(att.1) + log(Unemployment.rate) + log(u.1),data=yearly.wide[yearly.wide$season!=1940 & yearly.wide$season>1920,],na.action=na.exclude))

#table 1 top
stargazer(att.ue.all.1a,att.ue.all.2a,att.ue.all.0a)

#table 1 bottom
stargazer(att.ue.final.1a,att.ue.final.2a,att.ue.final.3a,att.ue.final.4a,att.ue.final.0a)

#appendix table top
stargazer(att.ue.all.1,att.ue.all.2,att.ue.all.0)

#appendix table bottom
stargazer(att.ue.final.1,att.ue.final.2,att.ue.final.3,att.ue.final.4,att.ue.final.0)

##unit root testing 

urun <- adf.test(yearly.wide$Unemployment.rate)
uruna <- adf.test(yearly.wide$Unemployment.rate[yearly.wide$season>1920])
ur0 <- adf.test(yearly.wide$attendance.cup)
ur0a <- adf.test(yearly.wide$attendance.cup[yearly.wide$season>1920])
ur1 <- adf.test(yearly.wide$attendance.EPL)
ur1a <- adf.test(yearly.wide$attendance.EPL[yearly.wide$season>1920])
ur2 <- adf.test(yearly.wide$attendance.EFLC[is.na(yearly.wide$attendance.EFLC)==FALSE])
ur2a <- adf.test(yearly.wide$attendance.EFLC[yearly.wide$season>1920 & is.na(yearly.wide$attendance.EFLC)==FALSE])
ur3 <- adf.test(yearly.wide$attendance.EFL1[is.na(yearly.wide$attendance.EFL1)==FALSE])
ur3a <- adf.test(yearly.wide$attendance.EFL1[yearly.wide$season!=1940 & yearly.wide$season>1920 & is.na(yearly.wide$attendance.EFL1)==FALSE])
ur4 <- adf.test(yearly.wide$attendance.EFL2[is.na(yearly.wide$attendance.EFL2)==FALSE])
ur4a <- adf.test(yearly.wide$attendance.EFL2[yearly.wide$season!=1940 & yearly.wide$season>1920 & is.na(yearly.wide$attendance.EFL2)==FALSE])

ur.tab <- c(urun$type1[1,3],ur1$type1[1,3],ur2$type1[1,3],ur0$type1[1,3])
ur.taba <- c(uruna$type1[1,3],ur1a$type1[1,3],ur2a$type1[1,3],ur3a$type1[1,3],ur4a$type1[1,3],ur0a$type1[1,3])

stargazer(ur.tab)
stargazer(ur.taba)

##create cointegrating vectors
yearly.att$fitted0[yearly.att$competition==0 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- fitted(att.ue.final.0)
yearly.att$fitted1[yearly.att$competition==1 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- fitted(att.ue.final.1)
yearly.att$fitted2[yearly.att$competition==2 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- fitted(att.ue.final.2)
yearly.att$fitted3[(yearly.att$competition==3 | yearly.att$competition==3.2) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- fitted(att.ue.final.3)
yearly.att$fitted4[(yearly.att$competition==4 | yearly.att$competition==3.1) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- fitted(att.ue.final.4)
yearly.att$fitted0a[yearly.att$competition==0 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- fitted(att.ue.final.0a)
yearly.att$fitted1a[yearly.att$competition==1 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- fitted(att.ue.final.1a)
yearly.att$fitted2a[yearly.att$competition==2 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- fitted(att.ue.final.2a)
yearly.att$fitted3a[(yearly.att$competition==3 | yearly.att$competition==3.2) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- fitted(att.ue.final.3a)
yearly.att$fitted4a[(yearly.att$competition==4 | yearly.att$competition==3.1) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- fitted(att.ue.final.4a)

yearly.att <- yearly.att[order(yearly.att$competition,yearly.att$season),]

##figure 2
#a
jpeg(paste0("actual-predicted-3-1-",Sys.Date(),".jpg"),height=6,width=10,units = "in",res = 300)
plot(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.1a$residuals) & yearly.att$season<1940],
     att.ue.final.1a$model$`log(attendance)`[1:19],
     main="Predicted and Actual Values (Premier League)",ylab="Log Attendance",xlab="Season",type="l",
     xlim=range(1920,2020),ylim=range(c(att.ue.final.1a$model$`log(attendance)`,
                                        att.ue.final.1a$fitted.values)))
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.1a$residuals) & yearly.att$season>1940],
     att.ue.final.1a$model$`log(attendance)`[20:93],type="l")
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.1a$residuals) & yearly.att$season<1940],
      att.ue.final.1a$fitted.values[1:19],
      lty=3)
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.1a$residuals) & yearly.att$season>1940],
      att.ue.final.1a$fitted.values[20:93],
      lty=3)
legend("bottom",lty=c(1,3),legend=c("Actual","Fitted"),bty="n",ncol = 2)
dev.off()

#b
jpeg(paste0("actual-predicted-3-2-",Sys.Date(),".jpg"),height=6,width=10,units = "in",res = 300)
plot(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.2a$residuals) & yearly.att$season<1940],
     att.ue.final.2a$model$`log(attendance)`[1:19],
     main="Predicted and Actual Values (Championship)",ylab="Log Attendance",xlab="Season",type="l",
     xlim=range(1920,2020),ylim=range(c(att.ue.final.2a$model$`log(attendance)`,
                                        att.ue.final.2a$fitted.values)))
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.2a$residuals) & yearly.att$season>1940],
     att.ue.final.2a$model$`log(attendance)`[20:93])
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.2a$residuals) & yearly.att$season<1940],
      att.ue.final.2a$fitted.values[1:19],
      lty=3)
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.2a$residuals) & yearly.att$season>1940],
      att.ue.final.2a$fitted.values[20:93],
      lty=3)
legend("bottom",lty=c(1,3),legend=c("Actual","Fitted"),bty="n",ncol = 2)
dev.off()

#c
jpeg(paste0("actual-predicted-3-3-",Sys.Date(),".jpg"),height=6,width=10,units = "in",res = 300)
plot(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.3a$residuals) & yearly.att$season<1940],
     att.ue.final.3a$model$`log(attendance)`[1:19],
     main="Predicted and Actual Values (League One)",ylab="Log Attendance",xlab="Season",type="l",
     xlim=range(1920,2020),ylim=range(c(att.ue.final.3a$model$`log(attendance)`,
                                        att.ue.final.3a$fitted.values)))
plot(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.3a$residuals) & yearly.att$season>1940],
     att.ue.final.3a$model$`log(attendance)`[20:93])
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.3a$residuals) & yearly.att$season<1940],
      att.ue.final.3a$fitted.values[1:19],
      lty=3)
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.3a$residuals) & yearly.att$season>1940],
      att.ue.final.3a$fitted.values[20:93],
      lty=3)
legend("bottom",lty=c(1,3),legend=c("Actual","Fitted"),bty="n",ncol = 2)
dev.off()

#d
jpeg(paste0("actual-predicted-3-4-",Sys.Date(),".jpg"),height=6,width=10,units = "in",res = 300)
plot(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.4a$residuals) & yearly.att$season<1940],
     att.ue.final.4a$model$`log(attendance)`[1:18],
     main="Predicted and Actual Values (League Two)",ylab="Log Attendance",xlab="Season",type="l",
     xlim=range(1920,2020),ylim=range(c(att.ue.final.4a$model$`log(attendance)`,
                                        att.ue.final.4a$fitted.values)))
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.4a$residuals) & yearly.att$season>1940],
     att.ue.final.4a$model$`log(attendance)`[19:92],type="l")
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.4a$residuals) & yearly.att$season<1940],
      att.ue.final.4a$fitted.values[1:18],
      lty=3)
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.4a$residuals) & yearly.att$season>1940],
      att.ue.final.4a$fitted.values[19:92],
      lty=3)
legend("bottom",lty=c(1,3),legend=c("Actual","Fitted"),bty="n",ncol = 2)
dev.off()

#e
jpeg(paste0("actual-predicted-3-0-",Sys.Date(),".jpg"),height=6,width=10,units = "in",res = 300)
plot(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.0a$residuals) & yearly.att$season<1940],
     att.ue.final.0a$model$`log(attendance)`[1:19],
     main="Predicted and Actual Values (Cups)",ylab="Log Attendance",xlab="Season",type="l",
     xlim=range(1920,2020),ylim=range(c(att.ue.final.0a$model$`log(attendance)`,
                                        att.ue.final.0a$fitted.values)))
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.0a$residuals) & yearly.att$season>1940],
      att.ue.final.0a$model$`log(attendance)`[20:93],
      type="l")
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.0a$residuals) & yearly.att$season<1940],
      att.ue.final.0a$fitted.values[1:19],
      lty=3)
lines(yearly.att$season[rownames(yearly.att) %in% names(att.ue.final.0a$residuals) & yearly.att$season>1940],
      att.ue.final.0a$fitted.values[20:93],
      lty=3)
legend("bottom",lty=c(1,3),legend=c("Actual","Fitted"),bty="n",ncol = 2)
dev.off()

##save residuals for Engle-Granger unit root testing
yearly.att$res0[yearly.att$competition==0 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- residuals(att.ue.final.0)
yearly.att$res1[yearly.att$competition==1 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- residuals(att.ue.final.1)
yearly.att$res2[yearly.att$competition==2 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- residuals(att.ue.final.2)
yearly.att$res3[(yearly.att$competition==3 | yearly.att$competition==3.2) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- residuals(att.ue.final.3)
yearly.att$res4[(yearly.att$competition==4 | yearly.att$competition==3.1) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940] <- residuals(att.ue.final.4)
yearly.att$res0a[yearly.att$competition==0 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- residuals(att.ue.final.0a)
yearly.att$res1a[yearly.att$competition==1 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- residuals(att.ue.final.1a)
yearly.att$res2a[yearly.att$competition==2 & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- residuals(att.ue.final.2a)
yearly.att$res3a[(yearly.att$competition==3 | yearly.att$competition==3.2) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- residuals(att.ue.final.3a)
yearly.att$res4a[(yearly.att$competition==4 | yearly.att$competition==3.1) & is.na(yearly.att$Unemployment.rate)==FALSE & yearly.att$season!=1940 & yearly.att$season>1920] <- residuals(att.ue.final.4a)

##cointegration testing
ci0 <- adf.test(yearly.att$res0)
ci1 <- adf.test(yearly.att$res1)
ci2 <- adf.test(yearly.att$res2)
ci3 <- adf.test(yearly.att$res3)
ci4 <- adf.test(yearly.att$res4)
ci0a <- adf.test(yearly.att$res0a)
ci1a <- adf.test(yearly.att$res1a)
ci2a <- adf.test(yearly.att$res2a)
ci3a <- adf.test(yearly.att$res3a)
ci4a <- adf.test(yearly.att$res4a)

ci.tab <- c(ci0$type1[1,3],ci1$type1[1,3],ci2$type1[1,3],ci3$type1[1,3],
            ci4$type1[1,3])
ci.taba <- c(ci0a$type1[1,3],ci1a$type1[1,3],ci2a$type1[1,3],ci3a$type1[1,3],
            ci4a$type1[1,3])

stargazer(ci.tab)
stargazer(ci.taba)

##fig 3: plot of vectors

jpeg(paste0("fig2-",Sys.Date(),".jpg"),height=6,width=10,units = "in",res = 300)
plot(yearly.att$season[yearly.att$season>1920],yearly.att$res0a[yearly.att$season>1920],type="l",col="grey",main="Cointegrating Vectors (Long Run relationships)",
     ylab="Log attendance deviation",xlab="Season (year ending)",
     sub="residuals = log(attendance) - alpha_hat - beta_hat*log(unemployment_rate)")
lines(yearly.att$season[yearly.att$season<1940],yearly.att$res1a[yearly.att$season<1940],type="l",lty=1)
lines(yearly.att$season[yearly.att$season>1940],yearly.att$res1a[yearly.att$season>1940],type="l",lty=1)

lines(yearly.att$season[yearly.att$season<1940],yearly.att$res2a[yearly.att$season<1940],type="l",lty=2)
lines(yearly.att$season[yearly.att$season>1940],yearly.att$res2a[yearly.att$season>1940],type="l",lty=2)

lines(yearly.att$season[yearly.att$season<1940],yearly.att$res3a[yearly.att$season<1940],type="l",lty=3)
lines(yearly.att$season[yearly.att$season>1940],yearly.att$res3a[yearly.att$season>1940],type="l",lty=3)

lines(yearly.att$season[yearly.att$season<1940],yearly.att$res4a[yearly.att$season<1940],type="l",lty=4)
lines(yearly.att$season[yearly.att$season>1940],yearly.att$res4a[yearly.att$season>1940],type="l",lty=4)

abline(v=c(1915,1919,1939,1945,1959))
abline(0,0,lty=3,col="red")
legend("bottomleft",col=c("grey",1,1,1,1),lty=c(1,1,2,3,4),
       legend=c("Cups","Premier League","Championship","League One","League Two"),bty="n",ncol = 3)
dev.off()



##robustness regressions - look at club-year level
summary(catt.reg <- felm(log(attendance) ~ log(Unemployment.rate) + log(Unemployment.rate):as.character(tier) + log(Unemployment.rate):as.character(club) | club + tier | 0 | club + tier,data=yearly.club[yearly.club$n.seasons>20 & yearly.club$season>1920,]))
getfe(catt.reg)
stargazer(catt.reg)
summary(catt.reg1 <- felm(log(attendance) ~ log(Unemployment.rate) + log(Unemployment.rate):as.character(competition) + log(Unemployment.rate):as.character(club) | club + competition | 0 | club + competition,data=yearly.club[yearly.club$n.seasons>20 & yearly.club$season>1920,]))
getfe(catt.reg1)
stargazer(catt.reg1)

##robustness regressions - look at individual match level
colnames(att.all)[colnames(att.all)=="team1"] <- "club"
summary(all.att.reg <- felm(log(attendance) ~ log(Unemployment.rate) + log(Unemployment.rate):as.character(tier) + log(Unemployment.rate):as.character(club) | club + tier | 0 | club + tier,data=att.all[yearly.club$season>1920,]))
